==> zio-aws-macie2_2.12-5.17.130.3-sources.jar: zio/aws/macie2/model/DeleteFindingsFilterRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DeleteFindingsFilterRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.DeleteFindingsFilterRequest = {
    import DeleteFindingsFilterRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.DeleteFindingsFilterRequest
      .builder()
      .id(__string.unwrap(id): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.DeleteFindingsFilterRequest.ReadOnly =
    zio.aws.macie2.model.DeleteFindingsFilterRequest.wrap(buildAwsValue())
}
object DeleteFindingsFilterRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.DeleteFindingsFilterRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.DeleteFindingsFilterRequest =
      zio.aws.macie2.model.DeleteFindingsFilterRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.DeleteFindingsFilterRequest
  ) extends zio.aws.macie2.model.DeleteFindingsFilterRequest.ReadOnly {
    override val id: __string =
      zio.aws.macie2.model.primitives.__string(impl.id())
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.DeleteFindingsFilterRequest
  ): zio.aws.macie2.model.DeleteFindingsFilterRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-macie2_2.12-5.20.7.1-sources.jar: zio/aws/macie2/model/DeleteFindingsFilterRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DeleteFindingsFilterRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.DeleteFindingsFilterRequest = {
    import DeleteFindingsFilterRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.DeleteFindingsFilterRequest
      .builder()
      .id(id: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.DeleteFindingsFilterRequest.ReadOnly =
    zio.aws.macie2.model.DeleteFindingsFilterRequest.wrap(buildAwsValue())
}
object DeleteFindingsFilterRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.DeleteFindingsFilterRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.DeleteFindingsFilterRequest =
      zio.aws.macie2.model.DeleteFindingsFilterRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.DeleteFindingsFilterRequest
  ) extends zio.aws.macie2.model.DeleteFindingsFilterRequest.ReadOnly {
    override val id: __string = impl.id(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.DeleteFindingsFilterRequest
  ): zio.aws.macie2.model.DeleteFindingsFilterRequest.ReadOnly = new Wrapper(
    impl
  )
}
